@@ -23,7 +23,11 @@ class IAMRolePolicies:
         document = {
             "Version": "2012-10-17",
             "Statement": [
-                {"Action": ["sts:AssumeRole"], "Effect": "Allow", "Principal": {"Service": [service_principal]},}
+                {
+                    "Action": ["sts:AssumeRole"],
+                    "Effect": "Allow",
+                    "Principal": {"Service": [service_principal]},
+                }
             ],
         }
         return document
@@ -43,7 +47,11 @@ class IAMRolePolicies:
         document = {
             "Version": "2012-10-17",
             "Statement": [
-                {"Action": ["sts:AssumeRole"], "Effect": "Allow", "Principal": {"Service": ["states.amazonaws.com"]},}
+                {
+                    "Action": ["sts:AssumeRole"],
+                    "Effect": "Allow",
+                    "Principal": {"Service": ["states.amazonaws.com"]},
+                }
             ],
         }
         return document
