@@ -20,6 +20,8 @@ class OpenApiEditor(object):
     _X_APIGW_INTEGRATION = "x-amazon-apigateway-integration"
     _X_APIGW_TAG_VALUE = "x-amazon-apigateway-tag-value"
     _X_APIGW_CORS = "x-amazon-apigateway-cors"
+    _X_APIGW_ENDPOINT_CONFIG = "x-amazon-apigateway-endpoint-configuration"
+    _SERVERS = "servers"
     _CONDITIONAL_IF = "Fn::If"
     _X_ANY_METHOD = "x-amazon-apigateway-any-method"
     _ALL_HTTP_METHODS = ["OPTIONS", "GET", "HEAD", "POST", "PUT", "DELETE", "PATCH"]
@@ -246,7 +248,7 @@ class OpenApiEditor(object):
     def add_timeout_to_method(self, api, path, method_name, timeout):
         """
         Adds a timeout to this path/method.
-        
+
         :param dict api: Reference to the related Api's properties as defined in the template.
         :param string path: Path name
         :param string method_name: Method name
@@ -260,7 +262,7 @@ class OpenApiEditor(object):
     def add_path_parameters_to_method(self, api, path, method_name, path_parameters):
         """
         Adds path parameters to this path + method
-        
+
         :param dict api: Reference to the related Api's properties as defined in the template.
         :param string path: Path name
         :param string method_name: Method name
@@ -334,6 +336,14 @@ class OpenApiEditor(object):
             if normalized_method_name != "options":
                 normalized_method_name = self._normalize_method_name(method_name)
                 # It is possible that the method could have two definitions in a Fn::If block.
+                if normalized_method_name not in self.get_path(path):
+                    raise InvalidDocumentException(
+                        [
+                            InvalidTemplateException(
+                                "Could not find {} in {} within DefinitionBody.".format(normalized_method_name, path)
+                            )
+                        ]
+                    )
                 for method_definition in self.get_method_contents(self.get_path(path)[normalized_method_name]):
                     # If no integration given, then we don't need to process this definition (could be AWS::NoValue)
                     if not self.method_definition_has_integration(method_definition):
@@ -427,6 +437,27 @@ class OpenApiEditor(object):
                 tag = {"name": name, self._X_APIGW_TAG_VALUE: value}
                 self.tags.append(tag)
 
+    def add_endpoint_config(self, disable_execute_api_endpoint):
+        """Add endpoint configuration to _X_APIGW_ENDPOINT_CONFIG header in open api definition
+
+        Following this guide:
+        https://docs.aws.amazon.com/apigateway/latest/developerguide/api-gateway-swagger-extensions-endpoint-configuration.html
+        https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-apigatewayv2-api.html#cfn-apigatewayv2-api-disableexecuteapiendpoint
+
+        :param boolean disable_execute_api_endpoint: Specifies whether clients can invoke your API by using the default execute-api endpoint.
+
+        """
+
+        DISABLE_EXECUTE_API_ENDPOINT = "disableExecuteApiEndpoint"
+
+        servers_configurations = self._doc.get(self._SERVERS, [{}])
+        for config in servers_configurations:
+            endpoint_configuration = config.get(self._X_APIGW_ENDPOINT_CONFIG, dict())
+            endpoint_configuration[DISABLE_EXECUTE_API_ENDPOINT] = disable_execute_api_endpoint
+            config[self._X_APIGW_ENDPOINT_CONFIG] = endpoint_configuration
+
+        self._doc[self._SERVERS] = servers_configurations
+
     def add_cors(
         self,
         allow_origins,
